* Courtesy of Auto Exec BBS (508) 833-0508
* For Clipper S87 & 5.01
*
*****************************************************************

PROCEDURE PRNTLOAN

*****************************************************************

* Prints a loan payment table, dividing each payment into
* principal and interest



PARAMETER principal, points, fees, interest_rate,  ;
  loan_term_months, first_day

PUBLIC monthnames[12]
monthnames[1] =  "JAN"
monthnames[2] =  "FEB"
monthnames[3] =  "MAR"
monthnames[4] =  "APR"
monthnames[5] =  "MAY"
monthnames[6] =  "JUN"
monthnames[7] =  "JUL"
monthnames[8] =  "AUG"
monthnames[9] =  "SEP"
monthnames[10] = "OCT"
monthnames[11] = "NOV"
monthnames[12] = "DEC"

* Loan_month counts months in loan term


PRIVATE loan_month


* Quit if not enough parameter

IF PCOUNT() < 5
   RETURN
ENDIF

* Quit if any parameters are not numeric

IF TYPE('points') != 'N'          .OR.  ;
   TYPE('fees') != 'N'            .OR. ; 
   TYPE('principal') != 'N'       .OR. ;
   TYPE('interest_rate') != 'N'   .OR. ;
   TYPE('loan_term_months') != 'N'
   RETURN
ENDIF

* Quit if principal, interest_rate, or loan period
* parameters are zero or negative, or if fees or points
* are negative

IF points < 0          .OR. ;
   fees < 0            .OR. ;
   principal <= 0      .OR. ;
   interest_rate <= 0  .OR. ;
   loan_term_months <= 0
   RETURN
ENDIF


* Convert character form to date

IF TYPE('first_day') = 'C'
   first_day = CTOD(first_day)
ENDIF

* Use first day of current month if start date is omitted or
* invalid
start_d=first_day
IF TYPE('first_day') != 'D' .OR. EMPTY(first_day)
   first_day = CTOD(STR(MONTH(DATE()))+"/01/"+STR(YEAR(DATE())))
ENDIF


ytd_int   = 0.0
tot_int   = 0.0
ytd_prin  = 0.0
tot_prin  = 0.0


page_no    = 0
loan_month = 1
line_count = 99                         && Trigger heading

month_no   = MONTH(first_day)
year_no    = YEAR(first_day)

* If interest rate is 1 or more, assume that field must be
* converted to decimal.  This will change 12.00 (12 percent)
* .12 decimal.

IF interest_rate >= 1.00
   interest_rate = interest_rate * .01
ENDIF


   
remaining_bal = ((principal * (100.00 + points))/100) + fees
monthly_pmt   = ROUND(PAYMENT(remaining_bal,interest_rate, ;
                loan_term_months),2)


* Work through loan term

DO WHILE loan_month <= loan_term_months
    IF line_count >= 23 .or. month_no=1 
        IF line_count <> 99
            @1,1 say "Press Any Key"
            inkey(0)
        ENDIF
        DO print_heading
    ENDIF

    * Compute monthly figures 

    interest_part = ROUND((remaining_bal * interest_rate/12),2)
    IF loan_month = loan_term_months
        principal_part = remaining_bal
        remaining_bal = 0
    ELSE
        principal_part = monthly_pmt - interest_part
        remaining_bal = remaining_bal - principal_part
    ENDIF


*   Print payment amount

    @ line_count,4   SAY loan_month         PICTURE "999"
    @ line_count,11  SAY SUBSTR(monthnames[month_no],1,3)
    @ line_count,15  SAY year_no            PICTURE "9999"

    @ line_count,21  SAY monthly_pmt        PICTURE "999,999.99"
    @ line_count,34  SAY interest_part      PICTURE "999,999.99"
    @ line_count,47  SAY principal_part     PICTURE "999,999.99"
    @ line_count,60  SAY remaining_bal;                          
                                         PICTURE "99,999,999.99"

*   Add to year-to-date and grand totals

    ytd_int    = ytd_int + interest_part
    tot_int    = tot_int + interest_part

    ytd_prin   = ytd_prin + principal_part

    month_no   = month_no + 1
    line_count = line_count + 1
    loan_month = loan_month + 1

*   If last payment of year or loan, print and reset yearly    
*   totals

    IF (month_no > 12) .OR. (loan_month > loan_term_months)
        year_no = year_no + 1
        month_no = 1
        line_count = line_count + 1
        @ line_count,6  SAY "TOTAL FOR YEAR: "+str(year_no-year(start_d),2)
        @ line_count,31 SAY ytd_int   PICTURE "99,999,999.99"
        @ line_count,44 SAY ytd_prin  PICTURE "99,999,999.99"
        ytd_int  = 0.00
        ytd_prin = 0.00
        line_count = line_count + 2
    ENDIF

ENDDO (while)

* All detail lines printed - print grand totals

?

WAIT "Press space bar to display total loan payment amounts"

DO show_totals WITH ;
   principal, interest_rate, loan_term_months, tot_int


RETURN

*****************************************************************

PROCEDURE PRINT_HEADING

*****************************************************************

* Prints headings for each screen, updates page number


CLEAR
page_no = page_no + 1
@ 1,23 SAY " MORTGAGE AMORTIZATION SCHEDULE"
@ 1,70 SAY "PAGE"
@ 1,75 SAY page_no PICTURE "999"
@ 3,20 SAY "PRINCIPAL:"
@ 3,39 SAY principal PICTURE "$ 99,999,999.99"

@ 4,20 SAY "LOAN FEES:"
@ 4,39 SAY fees      PICTURE "$ 99,999,999.99"
@ 5,20 SAY "POINTS:"
@ 5,49 SAY points    PICTURE "99.99"

@ 6,20 SAY "INTEREST RATE:"
@ 6,49 SAY interest_rate * 100 PICTURE "99.99%"
@ 7,20 SAY "TERM (MONTHS):"
@ 7,51 SAY loan_term_months PICTURE "999"

@ 8,64 SAY "REMAINING"
@ 9,5  SAY "NO"
@ 9,9  SAY "PAYMENT DATE"
@ 9,25 SAY "AMOUNT"
@ 9,36 SAY "INTEREST"
@ 9,48 SAY "PRINCIPAL"
@ 9,65 SAY "BALANCE"
line_count = 11
RETURN


*****************************************************************

PROCEDURE SHOW_TOTALS

*****************************************************************

* Displays detail lines


PARAMETER prinamt, intrate, loanmonths, totintpaid

CLEAR
page_no = page_no + 1
@ 1,20  SAY " MORTGAGE AMORTIZATION ESTIMATE"
@ 1,70  SAY "PAGE"
@ 1,75  SAY page_no PICTURE "999"

@ 3,20 SAY "PRINCIPAL:"
@ 3,39 SAY prinamt PICTURE "$ 99,999,999.99"
@ 4,20 SAY "LOAN FEES:"
@ 4,39 SAY fees      PICTURE "$ 99,999,999.99"
@ 5,20 SAY "POINTS:"
@ 5,49 SAY points    PICTURE "99.99"

@ 6,20 SAY "INTEREST RATE:"
@ 6,49 SAY intrate * 100 PICTURE "99.99%"
@ 7,20 SAY "TERM:"
@ 7,51 SAY loanmonths PICTURE "999"

@ 13,13 SAY "PRINCIPAL (Including FEES and POINTS):"
principal = ((prinamt * (100.00 + points))/100) + fees
@ 13,51 SAY  principal PICTURE "$99,999,999.99"

@ 14,13 SAY "TOTAL INTEREST PAID:"
@ 14,51 SAY totintpaid PICTURE "$99,999,999.99"
@ 15,13 SAY "TOTAL PAYMENTS:"
grand_tot_dollars = principal + totintpaid
@ 15,51 SAY grand_tot_dollars PICTURE "$99,999,999.99"


RETURN

*******************************************************************
FUNCTION PAYMENT
PARAMETER  Prin,Int, Yrs
PRIVATE N,D,I,Y

Y=Yrs
I=Int/12
D=1-(I+1)^-Y
RETURN(Prin*I/D)

